Module config

Module config 

Configuration options for a LexeWallet.

Structs

WalletEnv
A wallet environment, e.g. “prod-mainnet-sgx”.
WalletEnvConfig
A configuration for a wallet environment.
WalletEnvDbConfig
Database directory configuration for a specific wallet environment.
WalletUserConfig
A wallet configuration for a specific user and wallet environment.
WalletUserDbConfig
Database directory configuration for a specific user and wallet environment.

Enums

DeployEnv
Represents a validated DEPLOY_ENVIRONMENT configuration.
Network
A simple version of bitcoin::Network which impls FromStr and Display in a consistent way, and which isn’t #[non_exhaustive].