Configuration options for a LexeWallet.
Structs
- Wallet
Env - A wallet environment, e.g. “prod-mainnet-sgx”.
- Wallet
EnvConfig - A configuration for a wallet environment.
- Wallet
EnvDb Config - Database directory configuration for a specific wallet environment.
- Wallet
User Config - A wallet configuration for a specific user and wallet environment.
- Wallet
User DbConfig - Database directory configuration for a specific user and wallet environment.
Enums
- Deploy
Env - Represents a validated
DEPLOY_ENVIRONMENTconfiguration. - Network
- A simple version of
bitcoin::Networkwhich implsFromStrandDisplayin a consistent way, and which isn’t#[non_exhaustive].